@@ -20,11 +20,11 @@
     51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
+#include <QApplication>
 #include "maindialog.h"
 #include <obrender/render.h>
 #include "tree.h"
 
-#include <QX11Info>
 #include <X11/Xlib.h>
 
 using namespace Obconf;
@@ -33,11 +33,13 @@ extern RrInstance* rrinst; // defined in obconf-qt.cpp
 
 static int num_desktops;
 
+/*
 static void desktops_read_names();
 static void desktops_write_names();
 static void desktops_write_number();
 
 static void enable_stuff();
+*/
 
 void MainDialog::desktops_setup_tab() {
   num_desktops = tree_get_int("desktops/number", 4);
@@ -123,26 +125,36 @@ void MainDialog::desktops_write_names() {
   }
 
   tree_apply();
+
+  auto x11NativeInterface = qApp->nativeInterface<QNativeInterface::QX11Application>();
+  auto display = x11NativeInterface->display();
+
   /* make openbox re-set the property */
-  XDeleteProperty(QX11Info::display(), QX11Info::appRootWindow(),
-                  XInternAtom(QX11Info::display(), "_NET_DESKTOP_NAMES", False));
+  XDeleteProperty(display, XDefaultRootWindow(display),
+                  XInternAtom(display, "_NET_DESKTOP_NAMES", False));
 }
 
 void MainDialog::desktops_write_number() {
+
+  auto x11NativeInterface = qApp->nativeInterface<QNativeInterface::QX11Application>();
+  auto display = x11NativeInterface->display();
+  auto appRootWindow = XDefaultRootWindow(display);
+
   XEvent ce;
   tree_set_int("desktops/number", num_desktops);
   ce.xclient.type = ClientMessage;
   ce.xclient.message_type =
-    XInternAtom(QX11Info::display(), "_NET_NUMBER_OF_DESKTOPS", False);
-  ce.xclient.display = QX11Info::display();
-  ce.xclient.window = QX11Info::appRootWindow();
+    XInternAtom(display, "_NET_NUMBER_OF_DESKTOPS", False);
+  ce.xclient.display = display;
+  ce.xclient.window = appRootWindow;
   ce.xclient.format = 32;
   ce.xclient.data.l[0] = num_desktops;
   ce.xclient.data.l[1] = 0;
   ce.xclient.data.l[2] = 0;
   ce.xclient.data.l[3] = 0;
   ce.xclient.data.l[4] = 0;
-  XSendEvent(QX11Info::display(), QX11Info::appRootWindow(), FALSE,
+
+  XSendEvent(display, appRootWindow, FALSE,
              SubstructureNotifyMask | SubstructureRedirectMask,
              &ce);
 }
