@@ -587,19 +587,19 @@ D: Allestedsnærværende (på alle skriveborde)</translation>
 <context>
     <name>Obconf::MainDialog</name>
     <message>
-        <location filename="../theme.cpp" line="149"/>
+        <location filename="../theme.cpp" line="152"/>
         <source>Choose an Openbox theme</source>
         <translation>Vælg et Openbox-tema</translation>
     </message>
     <message>
-        <location filename="../desktops.cpp" line="65"/>
-        <location filename="../desktops.cpp" line="87"/>
-        <location filename="../desktops.cpp" line="99"/>
+        <location filename="../desktops.cpp" line="67"/>
+        <location filename="../desktops.cpp" line="89"/>
+        <location filename="../desktops.cpp" line="101"/>
         <source>(Unnamed desktop)</source>
         <translation>(unavngivet skrivebord)</translation>
     </message>
     <message>
-        <location filename="../mouse.cpp" line="57"/>
+        <location filename="../mouse.cpp" line="56"/>
         <source>Custom actions</source>
         <translation>Tilpassede handlinger</translation>
     </message>
@@ -657,7 +657,7 @@ Følgende fejl blev rapporteret:
     </message>
     <message>
         <location filename="../archive.cpp" line="95"/>
-        <location filename="../archive.cpp" line="178"/>
+        <location filename="../archive.cpp" line="180"/>
         <source>Unable to run the &quot;tar&quot; command: %1</source>
         <translation>Kan ikke køre &quot;tar&quot;-kommandoen: %1</translation>
     </message>
@@ -672,12 +672,7 @@ Følgende fejl blev rapporteret:
         <translation>&quot;%1&quot; ser ikke ud til at være en gyldig mappe til Openbox-temaer</translation>
     </message>
     <message>
-        <location filename="../archive.cpp" line="148"/>
-        <source>Unable to move to directory &quot;%1&quot;: %2</source>
-        <translation>Kan ikke flytte til mappen &quot;%1&quot;: %2</translation>
-    </message>
-    <message>
-        <location filename="../archive.cpp" line="185"/>
+        <location filename="../archive.cpp" line="187"/>
         <source>Unable to extract the file &quot;%1&quot;.
 Please ensure that &quot;%2&quot; is writable and that the file is a valid Openbox theme archive.
 The following errors were reported:
@@ -758,18 +753,30 @@ Tilvalg:
 </translation>
     </message>
     <message>
-        <location filename="../obconf-qt.cpp" line="223"/>
-        <location filename="../obconf-qt.cpp" line="238"/>
+        <location filename="../obconf-qt.cpp" line="206"/>
+        <source>Platform Unsupported</source>
+        <translation>Platform ikke understøttet</translation>
+    </message>
+    <message>
+        <location filename="../obconf-qt.cpp" line="207"/>
+        <source>ObConf-Qt is unsupported under Wayland.
+</source>
+        <translation>ObConf-Qt er ikke understøttet under Wayland.
+</translation>
+    </message>
+    <message>
+        <location filename="../obconf-qt.cpp" line="241"/>
+        <location filename="../obconf-qt.cpp" line="256"/>
         <source>Error</source>
         <translation>Fejl</translation>
     </message>
     <message>
-        <location filename="../obconf-qt.cpp" line="224"/>
+        <location filename="../obconf-qt.cpp" line="242"/>
         <source>Failed to load an rc.xml. You have probably failed to install Openbox properly.</source>
         <translation>Kunne ikke indlæse en rc.xml. Du har muligvis ikke fået installeret Openbox ordentligt.</translation>
     </message>
     <message>
-        <location filename="../obconf-qt.cpp" line="236"/>
+        <location filename="../obconf-qt.cpp" line="254"/>
         <source>Error while parsing the Openbox configuration file.  Your configuration file is not valid XML.
 
 Message: %1</source>
