@@ -587,9 +587,9 @@ D : Omniprésent (Sur tous les bureaux)</translation>
 <context>
     <name>Obconf::MainDialog</name>
     <message>
-        <location filename="../desktops.cpp" line="65"/>
-        <location filename="../desktops.cpp" line="87"/>
-        <location filename="../desktops.cpp" line="99"/>
+        <location filename="../desktops.cpp" line="67"/>
+        <location filename="../desktops.cpp" line="89"/>
+        <location filename="../desktops.cpp" line="101"/>
         <source>(Unnamed desktop)</source>
         <translation>(Bureau sans nom)</translation>
     </message>
@@ -624,12 +624,12 @@ Lee programme est basé sur ObConf developpé par :
 * Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</translation>
     </message>
     <message>
-        <location filename="../mouse.cpp" line="57"/>
+        <location filename="../mouse.cpp" line="56"/>
         <source>Custom actions</source>
         <translation>Actions personnalisées</translation>
     </message>
     <message>
-        <location filename="../theme.cpp" line="149"/>
+        <location filename="../theme.cpp" line="152"/>
         <source>Choose an Openbox theme</source>
         <translation>Choisir un thème Openbox</translation>
     </message>
@@ -657,14 +657,14 @@ Les erreurs suivantes ont été signalées :
     </message>
     <message>
         <location filename="../archive.cpp" line="95"/>
-        <location filename="../archive.cpp" line="178"/>
+        <location filename="../archive.cpp" line="180"/>
         <source>Unable to run the &quot;tar&quot; command: %1</source>
         <translation>Impossible d’exécuter la commande &quot;tar&quot; : %1</translation>
     </message>
     <message>
         <location filename="../archive.cpp" line="115"/>
         <source>Unable to create directory &quot;%1&quot;: %2</source>
-        <translation>Impossible de créer le répertoire &quot;%1&quot;&#x202f;: %2</translation>
+        <translation>Impossible de créer le dossier &quot;%1&quot; : %2</translation>
     </message>
     <message>
         <location filename="../archive.cpp" line="138"/>
@@ -672,12 +672,7 @@ Les erreurs suivantes ont été signalées :
         <translation>&quot;%1&quot; ne semble pas être un répertoire avec un thème valide pour Openbox</translation>
     </message>
     <message>
-        <location filename="../archive.cpp" line="148"/>
-        <source>Unable to move to directory &quot;%1&quot;: %2</source>
-        <translation>Impossible de déplacer vers le répertoire &quot;%1&quot; : %2</translation>
-    </message>
-    <message>
-        <location filename="../archive.cpp" line="185"/>
+        <location filename="../archive.cpp" line="187"/>
         <source>Unable to extract the file &quot;%1&quot;.
 Please ensure that &quot;%2&quot; is writable and that the file is a valid Openbox theme archive.
 The following errors were reported:
@@ -709,7 +704,7 @@ Copyright (c) 2003        Tim Riley
 Copyright (c) 2007        Javeed Shaikh
 Copyright (c) 2013        Hong Jen Yee (PCMan)
 
-Ce programme est livré avec ABSOLUMENT AUCUNE GARANTIE.
+Ce programme est livré sans AUCUNE GARANTIE.
 C&apos;est un logiciel libre, et vous êtes les bienvenus pour le redistribuer
 sous certaines conditions. Voir le fichier COPYING pour plus de détails.
 
@@ -729,10 +724,10 @@ Options:
         <translation>Syntaxe : obconf [options] [ARCHIVE.obt]
 
 Options :
-  --help                Affiche l&apos;aide et quitté
-  --version             Affiche la version et quitté
-  --install ARCHIVE.obt   Installe le thème archive spécifié et sélectionné celui-ci
-  --archive THEME       Créé un thème archive depuis le répertoire de thème spécifié
+  --help                Affiche l&apos;aide et quitte
+  --version             Affiche la version et quitte
+  --install ARCHIVE.obt   Installer l&apos;archive du thème spécifié et le sélectionner
+  --archive THEME       Créé un une archive du thème depuis le dossier du thème spécifié
   --config-file FILE    Spécifie le chemin vers le fichier de configuration à utiliser
 </translation>
     </message>
@@ -740,36 +735,48 @@ Options :
         <location filename="../obconf-qt.cpp" line="97"/>
         <source>--install requires an argument
 </source>
-        <translation>--install demande un argument
+        <translation>--install nécessite un argument
 </translation>
     </message>
     <message>
         <location filename="../obconf-qt.cpp" line="103"/>
         <source>--archive requires an argument
 </source>
-        <translation>--archive demande un argument
+        <translation>--archive nécessite un argument
 </translation>
     </message>
     <message>
         <location filename="../obconf-qt.cpp" line="109"/>
         <source>--config-file requires an argument
 </source>
-        <translation>--config-file demande un argument
+        <translation>--config-file nécessite un argument
 </translation>
     </message>
     <message>
-        <location filename="../obconf-qt.cpp" line="223"/>
-        <location filename="../obconf-qt.cpp" line="238"/>
+        <location filename="../obconf-qt.cpp" line="206"/>
+        <source>Platform Unsupported</source>
+        <translation>Plateforme non prise en charge</translation>
+    </message>
+    <message>
+        <location filename="../obconf-qt.cpp" line="207"/>
+        <source>ObConf-Qt is unsupported under Wayland.
+</source>
+        <translation>ObConf-Qt n&apos;est pas pris en charge par Wayland.
+</translation>
+    </message>
+    <message>
+        <location filename="../obconf-qt.cpp" line="241"/>
+        <location filename="../obconf-qt.cpp" line="256"/>
         <source>Error</source>
         <translation>Erreur</translation>
     </message>
     <message>
-        <location filename="../obconf-qt.cpp" line="224"/>
+        <location filename="../obconf-qt.cpp" line="242"/>
         <source>Failed to load an rc.xml. You have probably failed to install Openbox properly.</source>
         <translation>Échec au chargement d&apos;un fichier rc.xml. Vous n&apos;avez probablement pas installé correctement Openbox.</translation>
     </message>
     <message>
-        <location filename="../obconf-qt.cpp" line="236"/>
+        <location filename="../obconf-qt.cpp" line="254"/>
         <source>Error while parsing the Openbox configuration file.  Your configuration file is not valid XML.
 
 Message: %1</source>
