@@ -19,7 +19,7 @@
     <message>
         <location filename="../obconf.ui" line="14"/>
         <source>Window Manager Preferences</source>
-        <translation>Vensterbeheerder-instellingen</translation>
+        <translation>Vensterbeheerderinstellingen</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="26"/>
@@ -587,19 +587,19 @@ D: Aanwezig op alle werkbladen</translation>
 <context>
     <name>Obconf::MainDialog</name>
     <message>
-        <location filename="../theme.cpp" line="149"/>
+        <location filename="../theme.cpp" line="152"/>
         <source>Choose an Openbox theme</source>
         <translation>Kies een thema voor Openbox</translation>
     </message>
     <message>
-        <location filename="../desktops.cpp" line="65"/>
-        <location filename="../desktops.cpp" line="87"/>
-        <location filename="../desktops.cpp" line="99"/>
+        <location filename="../desktops.cpp" line="67"/>
+        <location filename="../desktops.cpp" line="89"/>
+        <location filename="../desktops.cpp" line="101"/>
         <source>(Unnamed desktop)</source>
         <translation>(Naamloos werkblad)</translation>
     </message>
     <message>
-        <location filename="../mouse.cpp" line="57"/>
+        <location filename="../mouse.cpp" line="56"/>
         <source>Custom actions</source>
         <translation>Aangepaste acties</translation>
     </message>
@@ -657,7 +657,7 @@ De volgende fouten zijn opgetreden:
     </message>
     <message>
         <location filename="../archive.cpp" line="95"/>
-        <location filename="../archive.cpp" line="178"/>
+        <location filename="../archive.cpp" line="180"/>
         <source>Unable to run the &quot;tar&quot; command: %1</source>
         <translation>Kon &quot;tar&quot; opdracht %1 niet uitvoeren</translation>
     </message>
@@ -672,12 +672,7 @@ De volgende fouten zijn opgetreden:
         <translation>&quot;%1&quot; lijkt geen geldige map te zijn voor Openbox-thema&apos;s</translation>
     </message>
     <message>
-        <location filename="../archive.cpp" line="148"/>
-        <source>Unable to move to directory &quot;%1&quot;: %2</source>
-        <translation>Kon niet verplaatsen naar map &quot;%1&quot;: %2</translation>
-    </message>
-    <message>
-        <location filename="../archive.cpp" line="185"/>
+        <location filename="../archive.cpp" line="187"/>
         <source>Unable to extract the file &quot;%1&quot;.
 Please ensure that &quot;%2&quot; is writable and that the file is a valid Openbox theme archive.
 The following errors were reported:
@@ -757,7 +752,19 @@ Opties:
 </translation>
     </message>
     <message>
-        <location filename="../obconf-qt.cpp" line="236"/>
+        <location filename="../obconf-qt.cpp" line="206"/>
+        <source>Platform Unsupported</source>
+        <translation>Geen ondersteund platform</translation>
+    </message>
+    <message>
+        <location filename="../obconf-qt.cpp" line="207"/>
+        <source>ObConf-Qt is unsupported under Wayland.
+</source>
+        <translation>ObConf-Qt wordt niet ondersteund op Wayland.
+</translation>
+    </message>
+    <message>
+        <location filename="../obconf-qt.cpp" line="254"/>
         <source>Error while parsing the Openbox configuration file.  Your configuration file is not valid XML.
 
 Message: %1</source>
@@ -766,15 +773,15 @@ Message: %1</source>
 Boodschap: %1</translation>
     </message>
     <message>
-        <location filename="../obconf-qt.cpp" line="223"/>
-        <location filename="../obconf-qt.cpp" line="238"/>
+        <location filename="../obconf-qt.cpp" line="241"/>
+        <location filename="../obconf-qt.cpp" line="256"/>
         <source>Error</source>
         <translation>Foutmelding</translation>
     </message>
     <message>
-        <location filename="../obconf-qt.cpp" line="224"/>
+        <location filename="../obconf-qt.cpp" line="242"/>
         <source>Failed to load an rc.xml. You have probably failed to install Openbox properly.</source>
-        <translation>Kon bestand rc.xml niet laden. U hebt Openbox waarschijnlijk niet juist geïnstalleerd.</translation>
+        <translation>Kon bestand rc.xml niet laden. U heeft Openbox waarschijnlijk niet juist geïnstalleerd.</translation>
     </message>
 </context>
 </TS>
