@@ -239,7 +239,7 @@
     <message>
         <location filename="../obconf.ui" line="773"/>
         <source>Maximizes the window</source>
-        <translation type="unfinished"></translation>
+        <translation>ਵਿੰਡੋ ਨੂੰ ਵੱਧ ਤੋਂ ਵੱਧ ਕਰੋ</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="778"/>
@@ -280,7 +280,7 @@ D: Omnipresent (On all desktops)</source>
     <message>
         <location filename="../obconf.ui" line="1055"/>
         <source>Top Left</source>
-        <translation type="unfinished"></translation>
+        <translation>ਉੱਤੇ ਖੱਬੇ</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1060"/>
@@ -315,17 +315,17 @@ D: Omnipresent (On all desktops)</source>
     <message>
         <location filename="../obconf.ui" line="1090"/>
         <source>Bottom Right</source>
-        <translation type="unfinished"></translation>
+        <translation>ਹੇਠਾਂ ਸੱਜੇ</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1095"/>
         <source>Floating</source>
-        <translation type="unfinished"></translation>
+        <translation>ਤਰਦਾ</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1109"/>
         <source>&amp;Floating position:</source>
-        <translation type="unfinished"></translation>
+        <translation>ਤਰਨ ਦੀ ਸਥਿਤੀ(&amp;F):</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1134"/>
@@ -340,17 +340,17 @@ D: Omnipresent (On all desktops)</source>
     <message>
         <location filename="../obconf.ui" line="1157"/>
         <source>&amp;Orientation: </source>
-        <translation type="unfinished"></translation>
+        <translation>ਸਥਿਤੀ(&amp;O): </translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1171"/>
         <source>Vertical</source>
-        <translation type="unfinished"></translation>
+        <translation>ਖੜ੍ਹਵੀਂ</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1176"/>
         <source>Horizontal</source>
-        <translation type="unfinished"></translation>
+        <translation>ਲੇਟਵੀਂ</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1187"/>
@@ -360,7 +360,7 @@ D: Omnipresent (On all desktops)</source>
     <message>
         <location filename="../obconf.ui" line="1193"/>
         <source>Keep dock &amp;above other windows</source>
-        <translation type="unfinished"></translation>
+        <translation>ਹੋਰ ਵਿੰਡੋਆਂ ਦੇ ਉੱਤੇ ਡੌਕ ਕਰੋ(&amp;a)</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1200"/>
@@ -375,17 +375,17 @@ D: Omnipresent (On all desktops)</source>
     <message>
         <location filename="../obconf.ui" line="1217"/>
         <source>Hiding</source>
-        <translation type="unfinished"></translation>
+        <translation>ਓਹਲੇ</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1223"/>
         <source>&amp;Delay before hiding:</source>
-        <translation type="unfinished"></translation>
+        <translation>ਓਹਲੇ ਕਰਨ ਤੋਂ ਪਹਿਲਾਂ ਦੇਰੀ(&amp;D):</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1233"/>
         <source>Delay before &amp;showing:</source>
-        <translation type="unfinished"></translation>
+        <translation>ਵੇਖਾਉਣ ਤੋਂ ਪਹਿਲਾਂ ਦੇਰੀ(&amp;s):</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1263"/>
@@ -400,7 +400,7 @@ D: Omnipresent (On all desktops)</source>
     <message>
         <location filename="../obconf.ui" line="84"/>
         <source>&amp;Install a new theme...</source>
-        <translation type="unfinished"></translation>
+        <translation>ਨਵਾਂ ਥੀਮ ਇੰਸਟਾਲ ਕਰੋ(&amp;I)...</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="91"/>
@@ -430,27 +430,27 @@ D: Omnipresent (On all desktops)</source>
     <message>
         <location filename="../obconf.ui" line="239"/>
         <source>Menu &amp;header: </source>
-        <translation type="unfinished"></translation>
+        <translation>ਮੇਨੂ ਹੈੱਡਰ(&amp;h): </translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="249"/>
         <source>&amp;Menu Item: </source>
-        <translation type="unfinished"></translation>
+        <translation>ਮੇਨੂ ਆਈਟਮ(&amp;M): </translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="259"/>
         <source>Active &amp;On-screen display: </source>
-        <translation type="unfinished"></translation>
+        <translation>ਆਨ-ਸਕਰੀਨ ਡਿਸਪਲੇਅ ਸਰਗਰਮ ਕਰੋ(&amp;O): </translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="269"/>
         <source>Inactive O&amp;n-screen display: </source>
-        <translation type="unfinished"></translation>
+        <translation>ਆਨ-ਸਕਰੀਨ ਡਿਸਪਲੇਅ ਨਾ-ਸਰਗਰਮ ਕਰੋ(&amp;n): </translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="283"/>
         <source>Focus &amp;new windows when they appear</source>
-        <translation type="unfinished"></translation>
+        <translation>ਜਦੋਂ ਨਵੀਂ ਵਿੰਡੋ ਪ੍ਰਗਟ ਹੋਵੇ ਤਾਂ ਉਸ ਉੱਤੇ ਫੋਕਸ ਕਰੋ(&amp;n)</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="290"/>
@@ -470,17 +470,17 @@ D: Omnipresent (On all desktops)</source>
     <message>
         <location filename="../obconf.ui" line="358"/>
         <source>Primary &amp;monitor:</source>
-        <translation type="unfinished"></translation>
+        <translation>ਪ੍ਰਾਇਮਰੀ ਮਾਨੀਟਰ(&amp;m):</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="387"/>
         <source>&amp;Fixed monitor:</source>
-        <translation type="unfinished"></translation>
+        <translation>ਸਥਿਰ ਮਾਨੀਟਰ(&amp;F):</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="433"/>
         <source>Update the window contents while &amp;resizing</source>
-        <translation type="unfinished"></translation>
+        <translation>ਮੁੜ-ਆਕਾਰ ਕਰਨ ਦੌਰਾਨ ਵਿੰਡੋ ਸਮੱਗਰੀ ਨੂੰ ਅੱਪਡੇਟ ਕਰੋ(&amp;r)</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="440"/>
@@ -581,21 +581,21 @@ D: Omnipresent (On all desktops)</source>
 <context>
     <name>Obconf::MainDialog</name>
     <message>
-        <location filename="../mouse.cpp" line="57"/>
+        <location filename="../mouse.cpp" line="56"/>
         <source>Custom actions</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../desktops.cpp" line="65"/>
-        <location filename="../desktops.cpp" line="87"/>
-        <location filename="../desktops.cpp" line="99"/>
+        <location filename="../desktops.cpp" line="67"/>
+        <location filename="../desktops.cpp" line="89"/>
+        <location filename="../desktops.cpp" line="101"/>
         <source>(Unnamed desktop)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../maindialog.cpp" line="78"/>
         <source>About ObConf-Qt</source>
-        <translation type="unfinished"></translation>
+        <translation>ObConf-Qt ਬਾਰੇ</translation>
     </message>
     <message>
         <location filename="../maindialog.cpp" line="79"/>
@@ -613,7 +613,7 @@ The program is based on ObConf developed by the following developers.
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../theme.cpp" line="149"/>
+        <location filename="../theme.cpp" line="152"/>
         <source>Choose an Openbox theme</source>
         <translation type="unfinished"></translation>
     </message>
@@ -639,7 +639,7 @@ The following errors were reported:
     </message>
     <message>
         <location filename="../archive.cpp" line="95"/>
-        <location filename="../archive.cpp" line="178"/>
+        <location filename="../archive.cpp" line="180"/>
         <source>Unable to run the &quot;tar&quot; command: %1</source>
         <translation type="unfinished"></translation>
     </message>
@@ -654,12 +654,7 @@ The following errors were reported:
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../archive.cpp" line="148"/>
-        <source>Unable to move to directory &quot;%1&quot;: %2</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../archive.cpp" line="185"/>
+        <location filename="../archive.cpp" line="187"/>
         <source>Unable to extract the file &quot;%1&quot;.
 Please ensure that &quot;%2&quot; is writable and that the file is a valid Openbox theme archive.
 The following errors were reported:
@@ -703,18 +698,29 @@ Options:
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../obconf-qt.cpp" line="223"/>
-        <location filename="../obconf-qt.cpp" line="238"/>
+        <location filename="../obconf-qt.cpp" line="206"/>
+        <source>Platform Unsupported</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../obconf-qt.cpp" line="207"/>
+        <source>ObConf-Qt is unsupported under Wayland.
+</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../obconf-qt.cpp" line="241"/>
+        <location filename="../obconf-qt.cpp" line="256"/>
         <source>Error</source>
         <translation>ਗਲਤੀ</translation>
     </message>
     <message>
-        <location filename="../obconf-qt.cpp" line="224"/>
+        <location filename="../obconf-qt.cpp" line="242"/>
         <source>Failed to load an rc.xml. You have probably failed to install Openbox properly.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../obconf-qt.cpp" line="236"/>
+        <location filename="../obconf-qt.cpp" line="254"/>
         <source>Error while parsing the Openbox configuration file.  Your configuration file is not valid XML.
 
 Message: %1</source>
