@@ -261,7 +261,7 @@ I: Minimizar
 M: Maximizar
 C: Fechar
 S: Enrolar
-D: Omnipresente (todos os ambiente de trabalho)</translation>
+D: Omnipresente (em todas as áreas de trabalho)</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="332"/>
@@ -271,7 +271,7 @@ D: Omnipresente (todos os ambiente de trabalho)</translation>
     <message>
         <location filename="../obconf.ui" line="1013"/>
         <source>The dock is a special container for &quot;dockapps&quot;, or dock applications.  It is not visible on screen until a dockapp is run.  Dockapps can be used to show things like a clock, or to provide you with a system tray.</source>
-        <translation>A doca é uma área em que se colocam os ícones das aplicações ou &quot;dockapps&quot;. Esta área apenas está visível de estiver a executar uma &quot;dockapp&quot;. Com as &quot;dockapps&quot; pode  mostrar um relógio e mostrar a bandeja do sistema.</translation>
+        <translation>A doca é uma área em que se colocam os ícones das aplicações ou &quot;dockapps&quot;. Esta área apenas está visível de estiver a executar uma &quot;dockapp&quot;. Com as &quot;dockapps&quot; pode  mostrar um relógio e mostrar a área de notificação do sistema.</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1029"/>
@@ -421,7 +421,7 @@ D: Omnipresente (todos os ambiente de trabalho)</translation>
     <message>
         <location filename="../obconf.ui" line="115"/>
         <source>A&amp;nimate iconify and restore</source>
-        <translation>A&amp;nimar minimização e restauro</translation>
+        <translation>A&amp;nimar minimização e restaurar</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="219"/>
@@ -587,14 +587,14 @@ D: Omnipresente (todos os ambiente de trabalho)</translation>
 <context>
     <name>Obconf::MainDialog</name>
     <message>
-        <location filename="../mouse.cpp" line="57"/>
+        <location filename="../mouse.cpp" line="56"/>
         <source>Custom actions</source>
         <translation>Ações personalizadas</translation>
     </message>
     <message>
-        <location filename="../desktops.cpp" line="65"/>
-        <location filename="../desktops.cpp" line="87"/>
-        <location filename="../desktops.cpp" line="99"/>
+        <location filename="../desktops.cpp" line="67"/>
+        <location filename="../desktops.cpp" line="89"/>
+        <location filename="../desktops.cpp" line="101"/>
         <source>(Unnamed desktop)</source>
         <translation>(Ambiente de trabalho sem nome)</translation>
     </message>
@@ -629,7 +629,7 @@ Este programa foi baseado em ObConf, desenvolvido pelas pessoas abaixo indicadas
 * Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</translation>
     </message>
     <message>
-        <location filename="../theme.cpp" line="149"/>
+        <location filename="../theme.cpp" line="152"/>
         <source>Choose an Openbox theme</source>
         <translation>Escolha o tema Openbox</translation>
     </message>
@@ -657,7 +657,7 @@ Foram reportados os seguintes erros:
     </message>
     <message>
         <location filename="../archive.cpp" line="95"/>
-        <location filename="../archive.cpp" line="178"/>
+        <location filename="../archive.cpp" line="180"/>
         <source>Unable to run the &quot;tar&quot; command: %1</source>
         <translation>Não foi possível executar o comando &quot;tar&quot;: %1</translation>
     </message>
@@ -672,12 +672,7 @@ Foram reportados os seguintes erros:
         <translation>Parece que &quot;%1&quot; não é um diretório válido para temas Openbox</translation>
     </message>
     <message>
-        <location filename="../archive.cpp" line="148"/>
-        <source>Unable to move to directory &quot;%1&quot;: %2</source>
-        <translation>Não foi possível mover para o diretório &quot;%1&quot;: %2</translation>
-    </message>
-    <message>
-        <location filename="../archive.cpp" line="185"/>
+        <location filename="../archive.cpp" line="187"/>
         <source>Unable to extract the file &quot;%1&quot;.
 Please ensure that &quot;%2&quot; is writable and that the file is a valid Openbox theme archive.
 The following errors were reported:
@@ -735,18 +730,30 @@ Opções:
 </translation>
     </message>
     <message>
-        <location filename="../obconf-qt.cpp" line="223"/>
-        <location filename="../obconf-qt.cpp" line="238"/>
+        <location filename="../obconf-qt.cpp" line="206"/>
+        <source>Platform Unsupported</source>
+        <translation>Plataforma não suportada</translation>
+    </message>
+    <message>
+        <location filename="../obconf-qt.cpp" line="207"/>
+        <source>ObConf-Qt is unsupported under Wayland.
+</source>
+        <translation>O ObConf-Qt não é suportado pelo Wayland.
+</translation>
+    </message>
+    <message>
+        <location filename="../obconf-qt.cpp" line="241"/>
+        <location filename="../obconf-qt.cpp" line="256"/>
         <source>Error</source>
         <translation>Erro</translation>
     </message>
     <message>
-        <location filename="../obconf-qt.cpp" line="224"/>
+        <location filename="../obconf-qt.cpp" line="242"/>
         <source>Failed to load an rc.xml. You have probably failed to install Openbox properly.</source>
         <translation>Erro ao carregar rc.xml. É possível que o Openbox não esteja bem instalado.</translation>
     </message>
     <message>
-        <location filename="../obconf-qt.cpp" line="236"/>
+        <location filename="../obconf-qt.cpp" line="254"/>
         <source>Error while parsing the Openbox configuration file.  Your configuration file is not valid XML.
 
 Message: %1</source>
