@@ -45,7 +45,7 @@
     <message>
         <location filename="../obconf.ui" line="46"/>
         <source>Move &amp; Resize</source>
-        <translation>Перемещение и изменение размера</translation>
+        <translation>Перемещение и смена размера</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="51"/>
@@ -252,12 +252,12 @@ D: На все рабочие столы</translation>
     <message>
         <location filename="../obconf.ui" line="520"/>
         <source>&amp;Switch desktops when moving a window past the screen edge</source>
-        <translation>&amp;Переключать рабочие столы при перемещенииокна за границы экрана</translation>
+        <translation>&amp;Переключать рабочие столы при перемещении окна за границы экрана</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="530"/>
         <source>Information Dialog</source>
-        <translation>Информагионный диалог</translation>
+        <translation>Информационный диалог</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="537"/>
@@ -418,7 +418,7 @@ D: На все рабочие столы</translation>
     <message>
         <location filename="../obconf.ui" line="899"/>
         <source>Desktop margins are reserved areas on the edge of your screen.  New windows will not be placed within a margin, and maximized windows will not cover them.</source>
-        <translation>Границы рабочего стола - это зарезервированные зоны по вашего экрана. Новые окна не будут помещены в рамках границ, и развёрнутые окна не перекроют их.</translation>
+        <translation>Границы рабочего стола — это зарезервированные зоны по вашего экрана. Новые окна не будут помещены в рамках границ, и развёрнутые окна не перекроют их.</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="909"/>
@@ -451,7 +451,7 @@ D: На все рабочие столы</translation>
     <message>
         <location filename="../obconf.ui" line="1013"/>
         <source>The dock is a special container for &quot;dockapps&quot;, or dock applications.  It is not visible on screen until a dockapp is run.  Dockapps can be used to show things like a clock, or to provide you with a system tray.</source>
-        <translation>Док - это специальный контейнер для «dockapps», или приложений дока. Он не отображается на экране, пока не запущены эти приложения. Приложения дока могут быть использованы для показа таких вещей, как часы, или отображения системного лотка.</translation>
+        <translation>Док — это специальный контейнер для «dockapps» или приложений дока. Он не отображается на экране, если не запущены эти приложения. Приложения дока можно использовать для показа, например, часов или системного лотка.</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1029"/>
@@ -587,9 +587,9 @@ D: На все рабочие столы</translation>
 <context>
     <name>Obconf::MainDialog</name>
     <message>
-        <location filename="../desktops.cpp" line="65"/>
-        <location filename="../desktops.cpp" line="87"/>
-        <location filename="../desktops.cpp" line="99"/>
+        <location filename="../desktops.cpp" line="67"/>
+        <location filename="../desktops.cpp" line="89"/>
+        <location filename="../desktops.cpp" line="101"/>
         <source>(Unnamed desktop)</source>
         <translation>(Неназванный рабочий стол)</translation>
     </message>
@@ -624,12 +624,12 @@ Copyright (c) 2014-2015
 * Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</translation>
     </message>
     <message>
-        <location filename="../mouse.cpp" line="57"/>
+        <location filename="../mouse.cpp" line="56"/>
         <source>Custom actions</source>
         <translation>Индивидуальные действия</translation>
     </message>
     <message>
-        <location filename="../theme.cpp" line="149"/>
+        <location filename="../theme.cpp" line="152"/>
         <source>Choose an Openbox theme</source>
         <translation>Выбрать тему для Openbox</translation>
     </message>
@@ -657,7 +657,7 @@ The following errors were reported:
     </message>
     <message>
         <location filename="../archive.cpp" line="95"/>
-        <location filename="../archive.cpp" line="178"/>
+        <location filename="../archive.cpp" line="180"/>
         <source>Unable to run the &quot;tar&quot; command: %1</source>
         <translation>Не удалось выполнить команду «tar»: %1</translation>
     </message>
@@ -672,12 +672,7 @@ The following errors were reported:
         <translation>&quot;%1&quot; не является корректным каталогом тем Openbox</translation>
     </message>
     <message>
-        <location filename="../archive.cpp" line="148"/>
-        <source>Unable to move to directory &quot;%1&quot;: %2</source>
-        <translation>Невозможно переместить в каталог «%1»: %2</translation>
-    </message>
-    <message>
-        <location filename="../archive.cpp" line="185"/>
+        <location filename="../archive.cpp" line="187"/>
         <source>Unable to extract the file &quot;%1&quot;.
 Please ensure that &quot;%2&quot; is writable and that the file is a valid Openbox theme archive.
 The following errors were reported:
@@ -757,18 +752,29 @@ Options:
 </translation>
     </message>
     <message>
-        <location filename="../obconf-qt.cpp" line="223"/>
-        <location filename="../obconf-qt.cpp" line="238"/>
+        <location filename="../obconf-qt.cpp" line="206"/>
+        <source>Platform Unsupported</source>
+        <translation>Платформа не поддерживается</translation>
+    </message>
+    <message>
+        <location filename="../obconf-qt.cpp" line="207"/>
+        <source>ObConf-Qt is unsupported under Wayland.
+</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../obconf-qt.cpp" line="241"/>
+        <location filename="../obconf-qt.cpp" line="256"/>
         <source>Error</source>
         <translation>Ошибка</translation>
     </message>
     <message>
-        <location filename="../obconf-qt.cpp" line="224"/>
+        <location filename="../obconf-qt.cpp" line="242"/>
         <source>Failed to load an rc.xml. You have probably failed to install Openbox properly.</source>
         <translation>Не удалось загрузить rc.xml. Openbox, наверное, не установлен правильно.</translation>
     </message>
     <message>
-        <location filename="../obconf-qt.cpp" line="236"/>
+        <location filename="../obconf-qt.cpp" line="254"/>
         <source>Error while parsing the Openbox configuration file.  Your configuration file is not valid XML.
 
 Message: %1</source>
